/**
  *  \file server/prop.cc
  *  \brief Game Properties
  *
  *  c2file stores some game meta-information.
  *  This is passed to the JavaScript in obj/main->PROP.
  *  This module contains functions to manage these properties.
  *
  *  We do not have a way to modify these properties from the JavaScript.
  */

#include <map>
#include "server/prop.h"
#include "io/streams.h"
#include "io/textfile.h"
#include "server/jsonout.h"
#include "util/modinit.h"

static std::map<string_t, string_t> properties;

/** Load properties from a file.
    \param file File to read */
void
loadProperties(Stream& file)
{
    TextFile tf(file);
    tf.setUtf8();
    string_t line;
    while (tf.getLine(line)) {
        string_t::size_type n = line.find('=');
        if (n != line.npos && n > 5 && line.compare(0, 5, "prop:", 5) == 0) {
            setProperty(string_t(line, 5, n-5), string_t(line, n+1));
        }
    }
}

/** Set a property.
    \param name Property name
    \param value Property value */
void
setProperty(string_t name, string_t value)
{
    properties.insert(std::make_pair(name, value));
}

/** Write out properties in JSON format.
    Caller must call startObject() before and endObject() after this function.
    \param out Target */
void
writeProperties(JsonWriter& out)
{
    for (std::map<string_t, string_t>::iterator i = properties.begin(), e = properties.end(); i != e; ++i) {
        out.writeString(i->first, i->second);
    }
}

/** Clear all properties. */
void
clearProperties()
{
    properties.clear();
}


/*
 *  Initialisation
 */

const ModuleInitializer mod_prop[] = {
    { OnEnterDirectory | OnLeftDirectory, clearProperties },
    { 0, 0 },
};
